==> bucho-0.0.5.tar.gz: bucho-0.0.5/bucho/__init__.py <==
# encoding: utf-8
import json
import urllib

# these methods are exposed to Internet by wsgi.py
__all__ = ['show', 'latest_status', 'all_status', 'torumemo']

def show():
    """Say show :-)
    """
    _text="""
                                  #############                     ######## 
                                  #############                  ############## 
                                  #############                ################## 
                                  #############              ###################### 
                                     ########               ######################## 
                                    #######                ########################## 
                                    ######                ############################ 
                                   ######                ################        ###### 
                                   #####                 ##############            #### 
                                  #####                 ##############              #### 
                                  #####                 #############               #### 
                                  ####                  #############               #### 
                                  ####                  ############                #### 
                                  ####                 #############                #### 
                                  ####                 #############                #### 
                                  ####                #############                ##### 
                                  ####                #############               ##### 
                                  #####              ##############              ###### 
                                   ####              #############              ###### 
                                   #####            ##############             ####### 
                                    #####          ##############            ######## 
                                    ######       ################          ############# 
                                     ###########################           ############# 
                                      ##########################           ############# 
                                       ########################            ############# 
                                         #################### 
                                           ################ 
                                               ######### 
                                                         
                                  ####                                                                                   #### 
                                  ####                                                                                   #### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ####                                      ##### 
                                  ####                                        ##### 
                                                                               ##### 
                                                                                ##### 
                                                                                ###### 
                                                                                 ###### 
                                                                                 ###### 
                                                                                 ####### 
                                                                                 ####### 
                                                                                ######## 
                                  ####                                         ######### 
                                  ####                                      ############ 
                                  ###################################################### 
                                  ##################################################### 
                                  ##################################################### 
                                  #################################################### 
                                  ################################################### 
                                  ################################################# 
                                  ############################################## 
                                  ########################################## 
                                  #### 
                                  #### 
                                       
                                                    ################## 
                                               ############################ 
                                             ################################ 
                                           #################################### 
                                         ######################################## 
                                       ############################################ 
                                      ############################################## 
                                     #############                      ############# 
                                    #########                                ######### 
                                    #######                                    ####### 
                                   ######                                        ###### 
                                   #####                                          ##### 
                                  #####                                            ##### 
                                  ####                                              #### 
                                  ####                                              #### 
                                  ####                                              #### 
                                  ####                                              #### 
                                  #####                                            ##### 
                                  #####                                            ##### 
                                   #####                                          ##### 
                                   ######                                        ###### 
                                    #######                                    ####### 
                                    #########                                ######### 
                                     #############                      ############# 
                                      ############################################## 
                                       ############################################ 
                                         ######################################## 
                                           #################################### 
                                             ################################ 
                                               ############################ 
                                                    ################## 
                                                                       
                                                                                    #### 
                                                                                    #### 
                                                                                 ####### 
                                                                              ########## 
                                                                          ############## 
                                                                      ################## 
                                                                  ###################### 
                                                               ######################### 
                                                           ############################# 
                                                       ################################# 
                                                   ##################################### 
                                                ################################    #### 
                                            ################################        #### 
                                        ################################ 
                                    ################################# 
                                  ############################### 
                                     ######################## 
                                        ################# 
                                            ############ 
                                                ############ 
                                                   ############# 
                                                #################### 
                                            ############################ 
                                        ############################### 
                                    ################################ 
                                  ############################## 
                                     ######################## 
                                        ################# 
                                            ############ 
                                                ############ 
                                                    ############ 
                                                       ############# 
                                                           ############# 
                                                               #############        #### 
                                                                   #############    #### 
                                                                       ################# 
                                                                           ############# 
                                                                              ########## 
                                                                                  ###### 
                                                                                    #### 
                                                                                    #### 
                                                                                    #### 
    """
    return _text


def latest_status():
    """Print latest bucho's tweet.
    """
    url = urllib.urlopen('http://twitter.com/statuses/user_timeline/torufurukawa.json')
    tof = json.loads(url.read())
    return tof[0]['text']

def all_status():
    """Print all bucho's tweet.
    """
    url = urllib.urlopen('http://twitter.com/statuses/user_timeline/torufurukawa.json')
    tof = json.loads(url.read())
    for t in tof:
        return t['text']

def torumemo():
    """Open torumemo with webbrowser.
    """
    import webbrowser
    webbrowser.open("http://oldriver.org/torumemo/")

==> bucho-0.1.1.tar.gz: bucho-0.1.1/bucho/__init__.py <==
# encoding: utf-8
import json
import urllib

# these methods are exposed to Internet by wsgi.py
__all__ = ['show', 'latest_status', 'all_status', 'torumemo']

def show():
    """Say show :-)
    """
    _text="""
                                  #############                     ######## 
                                  #############                  ############## 
                                  #############                ################## 
                                  #############              ###################### 
                                     ########               ######################## 
                                    #######                ########################## 
                                    ######                ############################ 
                                   ######                ################        ###### 
                                   #####                 ##############            #### 
                                  #####                 ##############              #### 
                                  #####                 #############               #### 
                                  ####                  #############               #### 
                                  ####                  ############                #### 
                                  ####                 #############                #### 
                                  ####                 #############                #### 
                                  ####                #############                ##### 
                                  ####                #############               ##### 
                                  #####              ##############              ###### 
                                   ####              #############              ###### 
                                   #####            ##############             ####### 
                                    #####          ##############            ######## 
                                    ######       ################          ############# 
                                     ###########################           ############# 
                                      ##########################           ############# 
                                       ########################            ############# 
                                         #################### 
                                           ################ 
                                               ######### 
                                                         
                                  ####                                                                                   #### 
                                  ####                                                                                   #### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ########################################################################################### 
                                  ####                                      ##### 
                                  ####                                        ##### 
                                                                               ##### 
                                                                                ##### 
                                                                                ###### 
                                                                                 ###### 
                                                                                 ###### 
                                                                                 ####### 
                                                                                 ####### 
                                                                                ######## 
                                  ####                                         ######### 
                                  ####                                      ############ 
                                  ###################################################### 
                                  ##################################################### 
                                  ##################################################### 
                                  #################################################### 
                                  ################################################### 
                                  ################################################# 
                                  ############################################## 
                                  ########################################## 
                                  #### 
                                  #### 
                                       
                                                    ################## 
                                               ############################ 
                                             ################################ 
                                           #################################### 
                                         ######################################## 
                                       ############################################ 
                                      ############################################## 
                                     #############                      ############# 
                                    #########                                ######### 
                                    #######                                    ####### 
                                   ######                                        ###### 
                                   #####                                          ##### 
                                  #####                                            ##### 
                                  ####                                              #### 
                                  ####                                              #### 
                                  ####                                              #### 
                                  ####                                              #### 
                                  #####                                            ##### 
                                  #####                                            ##### 
                                   #####                                          ##### 
                                   ######                                        ###### 
                                    #######                                    ####### 
                                    #########                                ######### 
                                     #############                      ############# 
                                      ############################################## 
                                       ############################################ 
                                         ######################################## 
                                           #################################### 
                                             ################################ 
                                               ############################ 
                                                    ################## 
                                                                       
                                                                                    #### 
                                                                                    #### 
                                                                                 ####### 
                                                                              ########## 
                                                                          ############## 
                                                                      ################## 
                                                                  ###################### 
                                                               ######################### 
                                                           ############################# 
                                                       ################################# 
                                                   ##################################### 
                                                ################################    #### 
                                            ################################        #### 
                                        ################################ 
                                    ################################# 
                                  ############################### 
                                     ######################## 
                                        ################# 
                                            ############ 
                                                ############ 
                                                   ############# 
                                                #################### 
                                            ############################ 
                                        ############################### 
                                    ################################ 
                                  ############################## 
                                     ######################## 
                                        ################# 
                                            ############ 
                                                ############ 
                                                    ############ 
                                                       ############# 
                                                           ############# 
                                                               #############        #### 
                                                                   #############    #### 
                                                                       ################# 
                                                                           ############# 
                                                                              ########## 
                                                                                  ###### 
                                                                                    #### 
                                                                                    #### 
                                                                                    #### 
    """
    return _text


def latest_status():
    """Print latest bucho's tweet.
    """
    url = urllib.urlopen('http://twitter.com/statuses/user_timeline/torufurukawa.json')
    tof = json.loads(url.read().decode('ascii'))
    return tof[0]['text']

def all_status():
    """Print all bucho's tweet.
    """
    url = urllib.urlopen('http://twitter.com/statuses/user_timeline/torufurukawa.json')
    tof = json.loads(url.read().decode('ascii'))
    return u'\n'.join(t['text'] for t in tof)

def torumemo():
    """Open torumemo with webbrowser.
    """
    import webbrowser
    webbrowser.open("http://oldriver.org/torumemo/")
    return u'OK'
